ui

package
v1.7.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package ui handles user interaction, logging, and progress display.

Index

Constants

This section is empty.

Variables

Log is the global logger instance

Functions

func Debug added in v1.0.0

func Debug(msg string, args ...any)

Debug logs at Debug level

func Error added in v1.0.0

func Error(msg string, args ...any)

Error logs at Error level

func Info added in v1.0.0

func Info(msg string, args ...any)

Info logs at Info level

func NewProgressBar

func NewProgressBar(total int, description string) *progressbar.ProgressBar

NewProgressBar creates a progress bar with known total

func NewSpinner

func NewSpinner(description string) *progressbar.ProgressBar

NewSpinner creates a spinner for operations without known size

func Setup added in v1.0.0

func Setup(levelStr string)

Setup initializes the global logger with the specified level

func UpdateDescription

func UpdateDescription(bar *progressbar.ProgressBar, description string)

UpdateDescription updates the progress bar's description

func Warn added in v1.0.0

func Warn(msg string, args ...any)

Warn logs at Warn level

Types

This section is empty.

Jump to