github

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 15, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Default topic to search for agent skills
	SkillTopic = "agent-skill"
	APIURL     = "https://api.github.com/search/repositories"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Content

type Content struct {
	Name    string `json:"name"`
	Type    string `json:"type"`
	HTMLURL string `json:"html_url"`
}

Content represents a file or directory in a GitHub repository

type Repository

type Repository struct {
	Name            string    `json:"name"`
	FullName        string    `json:"full_name"`
	Description     string    `json:"description"`
	HTMLURL         string    `json:"html_url"`
	StargazersCount int       `json:"stargazers_count"`
	CloneURL        string    `json:"clone_url"`
	UpdatedAt       time.Time `json:"updated_at"`
	Source          string    `json:"-"` // Source name (e.g., "community", "anthropics")
	Owner           struct {
		Login string `json:"login"`
	} `json:"owner"`
}

func SearchDir

func SearchDir(owner, repo, path string) ([]Repository, error)

SearchDir searches a specific directory in a GitHub repository for subdirectories (skills)

func SearchTopic

func SearchTopic(topic, keyword string) ([]Repository, error)

SearchTopic searches GitHub for repositories with a specific topic and keyword

type SearchResult

type SearchResult struct {
	TotalCount int          `json:"total_count"`
	Items      []Repository `json:"items"`
}

Jump to