Documentation
¶
Overview ¶
Package repository manages skill repositories and sources.
Index ¶
- func FetchSkills(repo config.Repo) ([]github.Repository, error)
- func FetchSkillsFromRegistry(registryURL string, keyword string) ([]github.Repository, error)
- func FetchSkillsFromSkillHub(query string, _ string) ([]github.Repository, error)
- func FetchSkillsViaGit(repo config.Repo) ([]github.Repository, error)
- func ScanSkills(baseDir, subPath, owner, repoName string) ([]github.Repository, error)
- type RegistryIndex
- type RegistrySkill
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FetchSkills ¶
func FetchSkills(repo config.Repo) ([]github.Repository, error)
FetchSkills returns a list of skills available in the given repository
func FetchSkillsFromRegistry ¶ added in v1.7.5
func FetchSkillsFromRegistry(registryURL string, keyword string) ([]github.Repository, error)
FetchSkillsFromRegistry fetches skills from a registry index.json hosted on GitHub
func FetchSkillsFromSkillHub ¶ added in v0.8.0
func FetchSkillsFromSkillHub(query string, _ string) ([]github.Repository, error)
FetchSkillsFromSkillHub searches SkillHub and converts results to internal format
func FetchSkillsViaGit ¶ added in v0.8.0
func FetchSkillsViaGit(repo config.Repo) ([]github.Repository, error)
FetchSkillsViaGit clones a repo and discovers skills locally (no API needed)
func ScanSkills ¶ added in v1.0.0
func ScanSkills(baseDir, subPath, owner, repoName string) ([]github.Repository, error)
ScanSkills scans a directory recursively for skills
Types ¶
type RegistryIndex ¶ added in v1.7.5
type RegistryIndex struct {
Version string `json:"version"`
Skills []RegistrySkill `json:"skills"`
}
RegistryIndex represents the registry index.json structure
type RegistrySkill ¶ added in v1.7.5
type RegistrySkill struct {
Name string `json:"name"`
Source string `json:"source"`
URL string `json:"url"`
Description string `json:"description"`
Category string `json:"category"`
Tags []string `json:"tags"`
Stars int `json:"stars"`
Featured bool `json:"featured"`
InstallCmd string `json:"install_cmd"`
}
RegistrySkill represents a skill entry in the registry index
Click to show internal directories.
Click to hide internal directories.