Documentation
¶
Overview ¶
Package repository manages skill repositories and sources.
Index ¶
- func FetchSkills(repo config.Repo) ([]github.Repository, error)
- func FetchSkillsFromSkillHub(query string, _ string) ([]github.Repository, error)
- func FetchSkillsViaGit(repo config.Repo) ([]github.Repository, error)
- func ScanSkills(baseDir, subPath, owner, repoName string) ([]github.Repository, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FetchSkills ¶
func FetchSkills(repo config.Repo) ([]github.Repository, error)
FetchSkills returns a list of skills available in the given repository
func FetchSkillsFromSkillHub ¶ added in v0.8.0
func FetchSkillsFromSkillHub(query string, _ string) ([]github.Repository, error)
FetchSkillsFromSkillHub searches SkillHub and converts results to internal format
func FetchSkillsViaGit ¶ added in v0.8.0
func FetchSkillsViaGit(repo config.Repo) ([]github.Repository, error)
FetchSkillsViaGit clones a repo and discovers skills locally (no API needed)
func ScanSkills ¶ added in v1.0.0
func ScanSkills(baseDir, subPath, owner, repoName string) ([]github.Repository, error)
ScanSkills scans a directory recursively for skills
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.