Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FetchSkills ¶
func FetchSkills(repo config.Repo) ([]github.Repository, error)
FetchSkills returns a list of skills available in the given repository
func FetchSkillsFromSkillHub ¶ added in v0.8.0
func FetchSkillsFromSkillHub(query string, category string) ([]github.Repository, error)
FetchSkillsFromSkillHub searches SkillHub and converts results to internal format
func FetchSkillsViaGit ¶ added in v0.8.0
func FetchSkillsViaGit(repo config.Repo) ([]github.Repository, error)
FetchSkillsViaGit clones a repo and discovers skills locally (no API needed)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.