Documentation
¶
Overview ¶
Package ui handles user interaction, logging, and progress display.
Index ¶
- Variables
- func Debug(msg string, args ...any)
- func Error(msg string, args ...any)
- func Info(msg string, args ...any)
- func NewProgressBar(total int, description string) *progressbar.ProgressBar
- func NewSpinner(description string) *progressbar.ProgressBar
- func Setup(levelStr string)
- func UpdateDescription(bar *progressbar.ProgressBar, description string)
- func Warn(msg string, args ...any)
Constants ¶
This section is empty.
Variables ¶
var Log *slog.Logger
Log is the global logger instance
Functions ¶
func NewProgressBar ¶
func NewProgressBar(total int, description string) *progressbar.ProgressBar
NewProgressBar creates a progress bar with known total
func NewSpinner ¶
func NewSpinner(description string) *progressbar.ProgressBar
NewSpinner creates a spinner for operations without known size
func Setup ¶ added in v1.0.0
func Setup(levelStr string)
Setup initializes the global logger with the specified level
func UpdateDescription ¶
func UpdateDescription(bar *progressbar.ProgressBar, description string)
UpdateDescription updates the progress bar's description
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.